@@ -15,7 +15,7 @@ import atom3.neighbors as nb
 from atom3.structure import get_ca_pos_from_residues, get_ca_pos_from_atoms
 
 Pair = col.namedtuple(
-    'Pair', ['complex', 'df0', 'df1', 'pos_idx', 'neg_idx', 'srcs', 'id'])
+    'Pair', ['complex', 'df0', 'df1', 'pos_idx', 'neg_idx', 'srcs', 'id', 'sequences'])
 
 sem = mp.Semaphore()
 
